==> iaxmodem_1.1.1~dfsg.orig.tar.gz: iaxmodem-1.1.1/lib/spandsp/src/v22bis_tx_floating_rrc.h <==
#define PULSESHAPER_GAIN        1.000000f
#define PULSESHAPER_COEFF_SETS  40
static const float pulseshaper[PULSESHAPER_COEFF_SETS][9] =
{
    {
          -0.0047225799f,     /* Filter 0 */
          -0.0084017854f,
          -0.0087512705f,
           0.0088069151f,
           0.5113443423f,
           0.5113443422f,
           0.0088069150f,
          -0.0087512705f,
          -0.0084017854f
    },
    {
          -0.0044560627f,     /* Filter 1 */
          -0.0089299784f,
          -0.0111430081f,
           0.0023375926f,
           0.5628832742f,
           0.4603563001f,
           0.0144879379f,
          -0.0063308268f,
          -0.0077375780f
    },
    {
          -0.0040955757f,     /* Filter 2 */
          -0.0093085520f,
          -0.0134608686f,
          -0.0048652084f,
           0.6146393768f,
           0.4102392997f,
           0.0193418829f,
          -0.0039255892f,
          -0.0069531299f
    },
    {
          -0.0036459251f,     /* Filter 3 */
          -0.0095262914f,
          -0.0156592355f,
          -0.0127304083f,
           0.6662684960f,
           0.3612970480f,
           0.0233456667f,
          -0.0015775329f,
          -0.0060659391f
    },
    {
          -0.0031137078f,     /* Filter 4 */
          -0.0095747033f,
          -0.0176928206f,
          -0.0211706543f,
           0.7174186958f,
           0.3138144449f,
           0.0264912738f,
           0.0006739922f,
          -0.0050949150f
    },
    {
          -0.0025072439f,     /* Filter 5 */
          -0.0094482428f,
          -0.0195175151f,
          -0.0300826256f,
           0.7677341786f,
           0.2680550805f,
           0.0287849965f,
           0.0027928495f,
          -0.0040599976f
    },
    {
          -0.0018364509f,     /* Filter 6 */
          -0.0091444853f,
          -0.0210912336f,
          -0.0393474967f,
           0.8168580673f,
           0.2242592987f,
           0.0302465054f,
           0.0047466024f,
          -0.0029817423f
    },
    {
          -0.0011126906f,     /* Filter 7 */
          -0.0086642941f,
          -0.0223747662f,
          -0.0488316115f,
           0.8644361861f,
           0.1826424770f,
           0.0309077815f,
           0.0065069834f,
          -0.0018809527f
    },
    {
          -0.0003486070f,     /* Filter 8 */
          -0.0080118899f,
          -0.0233326132f,
          -0.0583874108f,
           0.9101203338f,
           0.1433934276f,
           0.0308119316f,
           0.0080502010f,
          -0.0007782996f
    },
    {
           0.0004421038f,     /* Filter 9 */
          -0.0071948793f,
          -0.0239337731f,
          -0.0678546589f,
           0.9535717032f,
           0.1066734699f,
           0.0300118637f,
           0.0093572179f,
           0.0003060784f
    },
    {
           0.0012449004f,     /* Filter 10 */
          -0.0062242175f,
          -0.0241525264f,
          -0.0770617470f,
           0.9944641631f,
           0.0726154565f,
           0.0285689605f,
           0.0104139109f,
           0.0013528956f
    },
    {
           0.0020446769f,     /* Filter 11 */
          -0.0051140981f,
          -0.0239691024f,
          -0.0858273278f,
           1.0324875613f,
           0.0413233951f,
           0.0265516451f,
           0.0112111290f,
           0.0023440604f
    },
    {
           0.0028260046f,     /* Filter 12 */
          -0.0038818095f,
          -0.0233703410f,
          -0.0939620315f,
           1.0673511303f,
           0.0128722494f,
           0.0240338606f,
           0.0117446951f,
           0.0032629820f
    },
    {
           0.0035734256f,     /* Filter 13 */
          -0.0025475002f,
          -0.0223501989f,
          -0.1012704788f,
           1.0987857647f,
          -0.0126918879f,
           0.0210936824f,
           0.0120153027f,
           0.0040948071f
    },
    {
           0.0042717487f,     /* Filter 14 */
          -0.0011339020f,
          -0.0209102209f,
          -0.1075533482f,
           1.1265473042f,
          -0.0353513115f,
           0.0178118270f,
           0.0120283162f,
           0.0048266759f
    },
    {
           0.0049063204f,     /* Filter 15 */
           0.0003340068f,
          -0.0190598540f,
          -0.1126096101f,
           1.1504189013f,
          -0.0551159112f,
           0.0142701967f,
           0.0117935356f,
           0.0054478772f
    },
    {
           0.0054633378f,     /* Filter 16 */
           0.0018293983f,
          -0.0168166384f,
          -0.1162389085f,
           1.1702128005f,
          -0.0720220989f,
           0.0105505105f,
           0.0113248682f,
           0.0059499999f
    },
    {
           0.0059300986f,     /* Filter 17 */
           0.0033240172f,
          -0.0142063354f,
          -0.1182439353f,
           1.1857731261f,
          -0.0861315420f,
           0.0067330166f,
           0.0106398969f,
           0.0063270335f
    },
    {
           0.0062952926f,     /* Filter 18 */
           0.0047886664f,
          -0.0112628308f,
          -0.1184330100f,
           1.1969766889f,
          -0.0975294679f,
           0.0028952510f,
           0.0097595312f,
           0.0065754012f
    },
    {
           0.0065492251f,     /* Filter 19 */
           0.0061937075f,
          -0.0080279745f,
          -0.1166224166f,
           1.2037346307f,
          -0.1063230130f,
          -0.0008890961f,
           0.0087074429f,
           0.0066939821f
    },
    {
           0.0066840559f,     /* Filter 20 */
           0.0075095974f,
          -0.0045512022f,
          -0.1126391143f,
           1.2059933265f,
          -0.1126391143f,
          -0.0045512022f,
           0.0075095974f,
           0.0066840559f
    },
    {
           0.0066939821f,     /* Filter 21 */
           0.0087074429f,
          -0.0008890961f,
          -0.1063230130f,
           1.2037346307f,
          -0.1166224167f,
          -0.0080279745f,
           0.0061937074f,
           0.0065492251f
    },
    {
           0.0065754012f,     /* Filter 22 */
           0.0097595313f,
           0.0028952510f,
          -0.0975294679f,
           1.1969766889f,
          -0.1184330100f,
          -0.0112628308f,
           0.0047886664f,
           0.0062952926f
    },
    {
           0.0063270335f,     /* Filter 23 */
           0.0106398969f,
           0.0067330166f,
          -0.0861315419f,
           1.1857731261f,
          -0.1182439353f,
          -0.0142063354f,
           0.0033240172f,
           0.0059300986f
    },
    {
           0.0059499999f,     /* Filter 24 */
           0.0113248682f,
           0.0105505105f,
          -0.0720220988f,
           1.1702128005f,
          -0.1162389085f,
          -0.0168166384f,
           0.0018293982f,
           0.0054633378f
    },
    {
           0.0054478772f,     /* Filter 25 */
           0.0117935356f,
           0.0142701967f,
          -0.0551159112f,
           1.1504189013f,
          -0.1126096102f,
          -0.0190598540f,
           0.0003340068f,
           0.0049063204f
    },
    {
           0.0048266759f,     /* Filter 26 */
           0.0120283162f,
           0.0178118270f,
          -0.0353513115f,
           1.1265473042f,
          -0.1075533483f,
          -0.0209102209f,
          -0.0011339020f,
           0.0042717487f
    },
    {
           0.0040948071f,     /* Filter 27 */
           0.0120153027f,
           0.0210936824f,
          -0.0126918879f,
           1.0987857646f,
          -0.1012704788f,
          -0.0223501990f,
          -0.0025475002f,
           0.0035734256f
    },
    {
           0.0032629820f,     /* Filter 28 */
           0.0117446951f,
           0.0240338606f,
           0.0128722494f,
           1.0673511303f,
          -0.0939620315f,
          -0.0233703410f,
          -0.0038818095f,
           0.0028260045f
    },
    {
           0.0023440604f,     /* Filter 29 */
           0.0112111290f,
           0.0265516451f,
           0.0413233951f,
           1.0324875612f,
          -0.0858273278f,
          -0.0239691024f,
          -0.0051140981f,
           0.0020446769f
    },
    {
           0.0013528956f,     /* Filter 30 */
           0.0104139109f,
           0.0285689605f,
           0.0726154565f,
           0.9944641630f,
          -0.0770617471f,
          -0.0241525264f,
          -0.0062242175f,
           0.0012449004f
    },
    {
           0.0003060784f,     /* Filter 31 */
           0.0093572179f,
           0.0300118637f,
           0.1066734700f,
           0.9535717031f,
          -0.0678546589f,
          -0.0239337731f,
          -0.0071948793f,
           0.0004421038f
    },
    {
          -0.0007782996f,     /* Filter 32 */
           0.0080502011f,
           0.0308119316f,
           0.1433934276f,
           0.9101203338f,
          -0.0583874108f,
          -0.0233326132f,
          -0.0080118899f,
          -0.0003486070f
    },
    {
          -0.0018809527f,     /* Filter 33 */
           0.0065069834f,
           0.0309077816f,
           0.1826424771f,
           0.8644361860f,
          -0.0488316115f,
          -0.0223747662f,
          -0.0086642941f,
          -0.0011126906f
    },
    {
          -0.0029817423f,     /* Filter 34 */
           0.0047466024f,
           0.0302465054f,
           0.2242592987f,
           0.8168580673f,
          -0.0393474967f,
          -0.0210912336f,
          -0.0091444853f,
          -0.0018364509f
    },
    {
          -0.0040599976f,     /* Filter 35 */
           0.0027928495f,
           0.0287849965f,
           0.2680550805f,
           0.7677341786f,
          -0.0300826256f,
          -0.0195175151f,
          -0.0094482428f,
          -0.0025072439f
    },
    {
          -0.0050949150f,     /* Filter 36 */
           0.0006739922f,
           0.0264912738f,
           0.3138144449f,
           0.7174186958f,
          -0.0211706543f,
          -0.0176928206f,
          -0.0095747033f,
          -0.0031137079f
    },
    {
          -0.0060659391f,     /* Filter 37 */
          -0.0015775329f,
           0.0233456667f,
           0.3612970481f,
           0.6662684959f,
          -0.0127304083f,
          -0.0156592355f,
          -0.0095262914f,
          -0.0036459251f
    },
    {
          -0.0069531299f,     /* Filter 38 */
          -0.0039255892f,
           0.0193418829f,
           0.4102392997f,
           0.6146393768f,
          -0.0048652084f,
          -0.0134608686f,
          -0.0093085520f,
          -0.0040955757f
    },
    {
          -0.0077375780f,     /* Filter 39 */
          -0.0063308268f,
           0.0144879379f,
           0.4603563001f,
           0.5628832742f,
           0.0023375926f,
          -0.0111430081f,
          -0.0089299784f,
          -0.0044560627f
    }
};

==> iaxmodem_1.2.0~dfsg.orig.tar.gz: iaxmodem-1.2.0/lib/spandsp/src/v22bis_tx_floating_rrc.h <==
#define TX_PULSESHAPER_GAIN        1.000000f
#define TX_PULSESHAPER_COEFF_SETS  40
static const float tx_pulseshaper[TX_PULSESHAPER_COEFF_SETS][9] =
{
    {
          -0.0047225799f,     /* Filter 0 */
          -0.0084017854f,
          -0.0087512705f,
           0.0088069151f,
           0.5113443423f,
           0.5113443422f,
           0.0088069150f,
          -0.0087512705f,
          -0.0084017854f
    },
    {
          -0.0044560627f,     /* Filter 1 */
          -0.0089299784f,
          -0.0111430081f,
           0.0023375926f,
           0.5628832742f,
           0.4603563001f,
           0.0144879379f,
          -0.0063308268f,
          -0.0077375780f
    },
    {
          -0.0040955757f,     /* Filter 2 */
          -0.0093085520f,
          -0.0134608686f,
          -0.0048652084f,
           0.6146393768f,
           0.4102392997f,
           0.0193418829f,
          -0.0039255892f,
          -0.0069531299f
    },
    {
          -0.0036459251f,     /* Filter 3 */
          -0.0095262914f,
          -0.0156592355f,
          -0.0127304083f,
           0.6662684960f,
           0.3612970480f,
           0.0233456667f,
          -0.0015775329f,
          -0.0060659391f
    },
    {
          -0.0031137078f,     /* Filter 4 */
          -0.0095747033f,
          -0.0176928206f,
          -0.0211706543f,
           0.7174186958f,
           0.3138144449f,
           0.0264912738f,
           0.0006739922f,
          -0.0050949150f
    },
    {
          -0.0025072439f,     /* Filter 5 */
          -0.0094482428f,
          -0.0195175151f,
          -0.0300826256f,
           0.7677341786f,
           0.2680550805f,
           0.0287849965f,
           0.0027928495f,
          -0.0040599976f
    },
    {
          -0.0018364509f,     /* Filter 6 */
          -0.0091444853f,
          -0.0210912336f,
          -0.0393474967f,
           0.8168580673f,
           0.2242592987f,
           0.0302465054f,
           0.0047466024f,
          -0.0029817423f
    },
    {
          -0.0011126906f,     /* Filter 7 */
          -0.0086642941f,
          -0.0223747662f,
          -0.0488316115f,
           0.8644361861f,
           0.1826424770f,
           0.0309077815f,
           0.0065069834f,
          -0.0018809527f
    },
    {
          -0.0003486070f,     /* Filter 8 */
          -0.0080118899f,
          -0.0233326132f,
          -0.0583874108f,
           0.9101203338f,
           0.1433934276f,
           0.0308119316f,
           0.0080502010f,
          -0.0007782996f
    },
    {
           0.0004421038f,     /* Filter 9 */
          -0.0071948793f,
          -0.0239337731f,
          -0.0678546589f,
           0.9535717032f,
           0.1066734699f,
           0.0300118637f,
           0.0093572179f,
           0.0003060784f
    },
    {
           0.0012449004f,     /* Filter 10 */
          -0.0062242175f,
          -0.0241525264f,
          -0.0770617470f,
           0.9944641631f,
           0.0726154565f,
           0.0285689605f,
           0.0104139109f,
           0.0013528956f
    },
    {
           0.0020446769f,     /* Filter 11 */
          -0.0051140981f,
          -0.0239691024f,
          -0.0858273278f,
           1.0324875613f,
           0.0413233951f,
           0.0265516451f,
           0.0112111290f,
           0.0023440604f
    },
    {
           0.0028260046f,     /* Filter 12 */
          -0.0038818095f,
          -0.0233703410f,
          -0.0939620315f,
           1.0673511303f,
           0.0128722494f,
           0.0240338606f,
           0.0117446951f,
           0.0032629820f
    },
    {
           0.0035734256f,     /* Filter 13 */
          -0.0025475002f,
          -0.0223501989f,
          -0.1012704788f,
           1.0987857647f,
          -0.0126918879f,
           0.0210936824f,
           0.0120153027f,
           0.0040948071f
    },
    {
           0.0042717487f,     /* Filter 14 */
          -0.0011339020f,
          -0.0209102209f,
          -0.1075533482f,
           1.1265473042f,
          -0.0353513115f,
           0.0178118270f,
           0.0120283162f,
           0.0048266759f
    },
    {
           0.0049063204f,     /* Filter 15 */
           0.0003340068f,
          -0.0190598540f,
          -0.1126096101f,
           1.1504189013f,
          -0.0551159112f,
           0.0142701967f,
           0.0117935356f,
           0.0054478772f
    },
    {
           0.0054633378f,     /* Filter 16 */
           0.0018293983f,
          -0.0168166384f,
          -0.1162389085f,
           1.1702128005f,
          -0.0720220989f,
           0.0105505105f,
           0.0113248682f,
           0.0059499999f
    },
    {
           0.0059300986f,     /* Filter 17 */
           0.0033240172f,
          -0.0142063354f,
          -0.1182439353f,
           1.1857731261f,
          -0.0861315420f,
           0.0067330166f,
           0.0106398969f,
           0.0063270335f
    },
    {
           0.0062952926f,     /* Filter 18 */
           0.0047886664f,
          -0.0112628308f,
          -0.1184330100f,
           1.1969766889f,
          -0.0975294679f,
           0.0028952510f,
           0.0097595312f,
           0.0065754012f
    },
    {
           0.0065492251f,     /* Filter 19 */
           0.0061937075f,
          -0.0080279745f,
          -0.1166224166f,
           1.2037346307f,
          -0.1063230130f,
          -0.0008890961f,
           0.0087074429f,
           0.0066939821f
    },
    {
           0.0066840559f,     /* Filter 20 */
           0.0075095974f,
          -0.0045512022f,
          -0.1126391143f,
           1.2059933265f,
          -0.1126391143f,
          -0.0045512022f,
           0.0075095974f,
           0.0066840559f
    },
    {
           0.0066939821f,     /* Filter 21 */
           0.0087074429f,
          -0.0008890961f,
          -0.1063230130f,
           1.2037346307f,
          -0.1166224167f,
          -0.0080279745f,
           0.0061937074f,
           0.0065492251f
    },
    {
           0.0065754012f,     /* Filter 22 */
           0.0097595313f,
           0.0028952510f,
          -0.0975294679f,
           1.1969766889f,
          -0.1184330100f,
          -0.0112628308f,
           0.0047886664f,
           0.0062952926f
    },
    {
           0.0063270335f,     /* Filter 23 */
           0.0106398969f,
           0.0067330166f,
          -0.0861315419f,
           1.1857731261f,
          -0.1182439353f,
          -0.0142063354f,
           0.0033240172f,
           0.0059300986f
    },
    {
           0.0059499999f,     /* Filter 24 */
           0.0113248682f,
           0.0105505105f,
          -0.0720220988f,
           1.1702128005f,
          -0.1162389085f,
          -0.0168166384f,
           0.0018293982f,
           0.0054633378f
    },
    {
           0.0054478772f,     /* Filter 25 */
           0.0117935356f,
           0.0142701967f,
          -0.0551159112f,
           1.1504189013f,
          -0.1126096102f,
          -0.0190598540f,
           0.0003340068f,
           0.0049063204f
    },
    {
           0.0048266759f,     /* Filter 26 */
           0.0120283162f,
           0.0178118270f,
          -0.0353513115f,
           1.1265473042f,
          -0.1075533483f,
          -0.0209102209f,
          -0.0011339020f,
           0.0042717487f
    },
    {
           0.0040948071f,     /* Filter 27 */
           0.0120153027f,
           0.0210936824f,
          -0.0126918879f,
           1.0987857646f,
          -0.1012704788f,
          -0.0223501990f,
          -0.0025475002f,
           0.0035734256f
    },
    {
           0.0032629820f,     /* Filter 28 */
           0.0117446951f,
           0.0240338606f,
           0.0128722494f,
           1.0673511303f,
          -0.0939620315f,
          -0.0233703410f,
          -0.0038818095f,
           0.0028260045f
    },
    {
           0.0023440604f,     /* Filter 29 */
           0.0112111290f,
           0.0265516451f,
           0.0413233951f,
           1.0324875612f,
          -0.0858273278f,
          -0.0239691024f,
          -0.0051140981f,
           0.0020446769f
    },
    {
           0.0013528956f,     /* Filter 30 */
           0.0104139109f,
           0.0285689605f,
           0.0726154565f,
           0.9944641630f,
          -0.0770617471f,
          -0.0241525264f,
          -0.0062242175f,
           0.0012449004f
    },
    {
           0.0003060784f,     /* Filter 31 */
           0.0093572179f,
           0.0300118637f,
           0.1066734700f,
           0.9535717031f,
          -0.0678546589f,
          -0.0239337731f,
          -0.0071948793f,
           0.0004421038f
    },
    {
          -0.0007782996f,     /* Filter 32 */
           0.0080502011f,
           0.0308119316f,
           0.1433934276f,
           0.9101203338f,
          -0.0583874108f,
          -0.0233326132f,
          -0.0080118899f,
          -0.0003486070f
    },
    {
          -0.0018809527f,     /* Filter 33 */
           0.0065069834f,
           0.0309077816f,
           0.1826424771f,
           0.8644361860f,
          -0.0488316115f,
          -0.0223747662f,
          -0.0086642941f,
          -0.0011126906f
    },
    {
          -0.0029817423f,     /* Filter 34 */
           0.0047466024f,
           0.0302465054f,
           0.2242592987f,
           0.8168580673f,
          -0.0393474967f,
          -0.0210912336f,
          -0.0091444853f,
          -0.0018364509f
    },
    {
          -0.0040599976f,     /* Filter 35 */
           0.0027928495f,
           0.0287849965f,
           0.2680550805f,
           0.7677341786f,
          -0.0300826256f,
          -0.0195175151f,
          -0.0094482428f,
          -0.0025072439f
    },
    {
          -0.0050949150f,     /* Filter 36 */
           0.0006739922f,
           0.0264912738f,
           0.3138144449f,
           0.7174186958f,
          -0.0211706543f,
          -0.0176928206f,
          -0.0095747033f,
          -0.0031137079f
    },
    {
          -0.0060659391f,     /* Filter 37 */
          -0.0015775329f,
           0.0233456667f,
           0.3612970481f,
           0.6662684959f,
          -0.0127304083f,
          -0.0156592355f,
          -0.0095262914f,
          -0.0036459251f
    },
    {
          -0.0069531299f,     /* Filter 38 */
          -0.0039255892f,
           0.0193418829f,
           0.4102392997f,
           0.6146393768f,
          -0.0048652084f,
          -0.0134608686f,
          -0.0093085520f,
          -0.0040955757f
    },
    {
          -0.0077375780f,     /* Filter 39 */
          -0.0063308268f,
           0.0144879379f,
           0.4603563001f,
           0.5628832742f,
           0.0023375926f,
          -0.0111430081f,
          -0.0089299784f,
          -0.0044560627f
    }
};
